#include <stdlib.h>
#include <stdio.h>
#include <gtk/gtk.h>

#define GUI_FILE "gui.glade"
GtkBuilder *builder;

void init_gui();
GtkWidget* get_widget(const gchar *widget_name);
void show_selected_text();
void show_message();


int main(int argc, char *argv[]) {
	gtk_init(&argc, &argv);
    init_gui();
    
    gtk_main();
    
	return 0;
}



void init_gui() {
    GtkWidget *window, *btn, *combo, *combo_entry;
    
   	GError *error;
    
    builder = gtk_builder_new();
	error = NULL;
	gtk_builder_add_from_file(builder, GUI_FILE, &error);
	if (error) {
		g_print("Błąd: %s\n", error->message);
		g_error_free(error);
		exit(1);
	}
    
	window = get_widget("wnd_main");
    g_signal_connect(G_OBJECT(window), "delete-event", G_CALLBACK(gtk_main_quit), NULL);
	btn = get_widget("btn_close");	
    g_signal_connect(G_OBJECT(btn), "clicked", G_CALLBACK(gtk_main_quit), NULL);
	btn = get_widget("btn_show_selected_text");	
    g_signal_connect(G_OBJECT(btn), "clicked", G_CALLBACK(show_selected_text), NULL);
    
    
    combo = get_widget("comboboxtext1");
    combo_entry = get_widget("comboboxtext-entry");
    
    /*
     * Przykład wyczyszczenia zawartości kontrolki GtkComboBoxText
     */
    gtk_combo_box_text_remove_all(GTK_COMBO_BOX_TEXT(combo));
    gtk_entry_set_text(GTK_ENTRY(combo_entry), "");
    
    /*
     * Przykład dynamicznego wypełnienia kontrolki GtkComboBoxText opcjami
     */
    gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(combo), "opcja_1", "Pozycja numer #1 (dynamic)");
    gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(combo), "opcja_2", "Pozycja numer #2 (dynamic)");
    gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(combo), "opcja_3", "Pozycja numer #3 (dynamic)");
    
    gtk_widget_show(window);
}



GtkWidget* get_widget(const gchar *widget_name) {
    return GTK_WIDGET(gtk_builder_get_object(builder, widget_name));
}



void show_selected_text() {
    GtkWidget *combo;
    gchar *selected_text;
    const gchar *option_id;
    GString *msg = g_string_new("");
    
    combo = get_widget("comboboxtext1");
    selected_text = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(combo));
    option_id = gtk_combo_box_get_active_id(GTK_COMBO_BOX(combo));
    
    if (option_id) {
        g_string_printf(msg, "option_id: %s,  text: '%s'", option_id, selected_text);
    } else {
        g_string_printf(msg, "option_id: NULL,  text: '%s'", selected_text);
    }
    
    show_message(msg->str);
    //g_print("%s\n", msg->str);
    
    g_string_free(msg, TRUE);
    g_free(selected_text);
}

void show_message(const char *message) {
    GtkWidget *dialog, *label, *content_area;
    GtkDialogFlags flags;

    /* Utwórz widżety */
    flags = GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT;
    dialog = gtk_dialog_new_with_buttons("Message",
                                       GTK_WINDOW(get_widget("wnd_main")),
                                       flags,
                                       "_OK",
                                       GTK_RESPONSE_NONE,
                                       NULL);
    content_area = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
    label = gtk_label_new(message);

    /* Zniszcz okienko dialogowe po wciśnięciu przycisku OK */
    g_signal_connect_swapped(dialog,
                           "response",
                           G_CALLBACK(gtk_widget_destroy),
                           dialog);

    /* Dodaj etykietę z komunikatem i pokaż ją w okienku dialogowym */
    gtk_container_add(GTK_CONTAINER(content_area), label);
    gtk_widget_show(label);
    gtk_dialog_run(GTK_DIALOG(dialog));
}
